@@ -123,23 +123,16 @@ def get_assembly_metadata_by_bioproject_accessions(bioproject_accessions: List[s
     """
     with DatasetsApiClient() as api_client:
         genome_api = DatasetsGenomeApi(api_client)
-        yield from iterate_reply(genome_api.assembly_descriptors_by_bioproject,
-                                 bioproject_accessions,
-                                 **kwargs)
+        yield from iterate_reply(genome_api.assembly_descriptors_by_bioproject, bioproject_accessions, **kwargs)
 
 
-def iterate_reply(genome_api_func,
-                  func_arg,
-                  **kwargs):
+def iterate_reply(genome_api_func, func_arg, **kwargs):
     page_token = None
     try:
         while True:
-            assembly_reply = genome_api_func(func_arg,
-                                             page_size=PAGE_SIZE_MAX,
-                                             page_token=page_token,
-                                             **kwargs)
+            assembly_reply = genome_api_func(func_arg, page_size=PAGE_SIZE_MAX, page_token=page_token, **kwargs)
             if not assembly_reply.assemblies:
-                print(f'No assemblies found for {func_arg}')
+                print(f"No assemblies found for {func_arg}")
                 return
             yield from assembly_reply.assemblies
             if assembly_reply.next_page_token:
@@ -147,4 +140,4 @@ def iterate_reply(genome_api_func,
             else:
                 return
     except DatasetsApiException as e:
-        print(f'Exception when calling GenomeApi: {e}\n')
+        print(f"Exception when calling GenomeApi: {e}\n")
